@@ -2,14 +2,16 @@
 
 # This scripts runs all BLAS tests against the BLAS implementation currently
 # selected through the alternatives system
-# (see "update-alternatives --display libblas.so.3").
-# The BLAS implentation can be overriden using LD_LIBRARY_PATH.
+# (see "update-alternatives --display libblas.so.3-${DEB_HOST_MULTIARCH}").
+# The BLAS implementation can be overriden using LD_LIBRARY_PATH.
 
 # This script creates a few temporary files in the current directory.
 
-PATH=$PATH:/usr/lib/libblas
+DEB_HOST_MULTIARCH=$(dpkg-architecture -q DEB_HOST_MULTIARCH)
 
-DATADIR=/usr/lib/libblas
+PATH=/usr/lib/${DEB_HOST_MULTIARCH}/blas:$PATH
+
+DATADIR=/usr/lib/${DEB_HOST_MULTIARCH}/blas
 
 # Test Fortran BLAS
 for p in s d c z
